@@ -1,11 +1,3 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::proto::gen::expression::property::Key;
 use crate::proto::gen::expression::{
     ArrayExpression, BinaryExpression, CallExpression, ConditionalExpression, Expression,
@@ -206,6 +198,11 @@ impl ExpressionVisitor for CheckSupportedExprVisitor {
             }
         } else if !SUPPORTED_EXPRESSION_FNS.contains(node.name.as_str()) {
             self.supported = false;
+        } else if node.name == "indexof" {
+            // We only support the array variant of indexof (not the string variant)
+            if !(args.len() == 2 && matches!(args[0].expr, Some(Expr::Array(_)))) {
+                self.supported = false;
+            }
         }
     }
 
