@@ -1,13 +1,5 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::expression::compiler::config::CompilationConfig;
-use datafusion::logical_plan::{lit, Expr};
+use datafusion::logical_expr::{lit, Expr};
 use vegafusion_core::error::{Result, VegaFusionError};
 use vegafusion_core::proto::gen::expression::Identifier;
 
@@ -17,7 +9,7 @@ pub fn compile_identifier(node: &Identifier, config: &CompilationConfig) -> Resu
     } else if let Some(value) = config.constants.get(&node.name) {
         value.clone()
     } else {
-        return Err(VegaFusionError::compilation(&format!(
+        return Err(VegaFusionError::compilation(format!(
             "No signal named {} in evaluation scope",
             node.name
         )));
