@@ -126,13 +126,13 @@ mod test_compile {
 
         let expr = parse("foo").unwrap();
         let result_expr = compile(&expr, &config, None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, lit(42));
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(42);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -140,7 +140,7 @@ mod test_compile {
     fn test_compile_unary_neg() {
         let expr = parse("-(23.5)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let expected_expr = Expr::Negative(Box::new(lit(23.5)));
         assert_eq!(result_expr, expected_expr);
@@ -148,7 +148,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(-23.5);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -156,7 +156,7 @@ mod test_compile {
     fn test_compile_unary_pos() {
         let expr = parse("+'72'").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         // plus prefix on a string should result in a numeric cast
         let expected_expr = Expr::Cast(Cast {
@@ -169,7 +169,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(72.0);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -177,7 +177,7 @@ mod test_compile {
     fn test_compile_unary_not() {
         let expr = parse("!32").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         // unary not should cast numeric value to boolean
         let expected_expr = Expr::ScalarFunction {
@@ -198,7 +198,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(false);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -206,7 +206,7 @@ mod test_compile {
     fn test_compile_conditional() {
         let expr = parse("32? 7: 9").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let expected_expr = Expr::Case(Case {
             expr: None,
@@ -232,7 +232,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(7.0);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -240,7 +240,7 @@ mod test_compile {
     fn test_compile_logical_boolean() {
         let expr = parse("false || true").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let expected_expr = Expr::BinaryExpr(BinaryExpr {
             left: Box::new(lit(false)),
@@ -253,7 +253,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(true);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -261,7 +261,7 @@ mod test_compile {
     fn test_compile_logical_non_boolean() {
         let expr = parse("5 && 55").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let expected_expr = Expr::Case(Case {
             expr: None,
@@ -287,7 +287,7 @@ mod test_compile {
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::from(55.0);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -295,7 +295,7 @@ mod test_compile {
     fn test_compile_binary_mixed() {
         let expr = parse("1 + +'2' + true * 10").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         // 1 + +'2'
         let t1 = Expr::BinaryExpr(BinaryExpr {
@@ -323,14 +323,14 @@ mod test_compile {
             right: Box::new(t2),
         });
 
-        println!("{:?}", result_expr);
+        println!("{result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::Float64(Some(13.0));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -340,14 +340,14 @@ mod test_compile {
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
         let expected_expr = concat(&[lit("2"), lit("4")]);
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::Utf8(Some("24".to_string()));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -365,14 +365,14 @@ mod test_compile {
             right: Box::new(lit(2.0)),
         });
 
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::Boolean(Some(true));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -383,14 +383,14 @@ mod test_compile {
 
         // Types don't match, so this is compiled to the literal `false`
         let expected_expr = lit(false);
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected_value = ScalarValue::Boolean(Some(false));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -403,7 +403,7 @@ mod test_compile {
             fun: Arc::new(array_constructor_udf()),
             args: vec![lit(1.0), lit(2.0), lit(3.0)],
         };
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -418,7 +418,7 @@ mod test_compile {
             Box::new(Field::new("item", DataType::Float64, true)),
         );
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -431,7 +431,7 @@ mod test_compile {
             fun: Arc::new(array_constructor_udf()),
             args: vec![],
         };
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value. Empty array is given Float64 data type
@@ -442,7 +442,7 @@ mod test_compile {
             Box::new(Field::new("item", DataType::Float64, true)),
         );
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -468,7 +468,7 @@ mod test_compile {
                 },
             ],
         };
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -495,7 +495,7 @@ mod test_compile {
             )),
         );
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -524,7 +524,7 @@ mod test_compile {
             ],
         };
 
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
         // Check evaluated value
@@ -537,7 +537,7 @@ mod test_compile {
             ),
         ]);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected_value);
     }
 
@@ -545,12 +545,12 @@ mod test_compile {
     fn test_eval_object_member() {
         let expr = parse("({a: 1, 'two': 2})['tw' + 'o']").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Float64(Some(2.0));
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -572,7 +572,7 @@ mod test_compile {
             right: Box::new(lit(3.0)),
         });
 
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
     }
 
@@ -587,7 +587,7 @@ mod test_compile {
         let schema = Schema::new(vec![two_field]);
         let schema = DFSchema::try_from(schema).unwrap();
         let result_expr = compile(&expr, &Default::default(), Some(&schema)).unwrap();
-        println!("compiled: {:?}", result_expr);
+        println!("compiled: {result_expr:?}");
 
         // Make some data
         let foo_array = Arc::new(Float64Array::from(vec![11.0, 22.0, 33.0])) as ArrayRef;
@@ -597,7 +597,7 @@ mod test_compile {
 
         match evaluated {
             ColumnarValue::Array(evaluated) => {
-                println!("evaluated: {:?}", evaluated);
+                println!("evaluated: {evaluated:?}");
                 let evaluated = evaluated.as_any().downcast_ref::<Float64Array>().unwrap();
                 let evaluated: Vec<_> = evaluated.iter().map(|v| v.unwrap()).collect();
                 assert_eq!(evaluated, vec![33.0, 66.0, 99.0])
@@ -632,12 +632,12 @@ mod test_compile {
         });
 
         assert_eq!(result_expr, expected_expr);
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         // Check evaluated value
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Float64(Some(7.0));
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -645,12 +645,12 @@ mod test_compile {
     fn test_eval_call_abs() {
         let expr = parse("abs(-2)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Float64(Some(2.0));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -658,12 +658,12 @@ mod test_compile {
     fn test_eval_call_pow() {
         let expr = parse("pow(3, 4)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Float64(Some(81.0));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -671,12 +671,12 @@ mod test_compile {
     fn test_eval_call_round() {
         let expr = parse("round(4.8)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Float64(Some(5.0));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -684,12 +684,12 @@ mod test_compile {
     fn test_eval_call_is_nan() {
         let expr = parse("isNaN(NaN + 4)").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::Boolean(Some(true));
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -697,12 +697,12 @@ mod test_compile {
     fn test_eval_length() {
         let expr = parse("length([1, 2, 3])").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::from(3.0);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -710,12 +710,12 @@ mod test_compile {
     fn test_eval_length_member() {
         let expr = parse("[1, 2, 3].length").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
         let expected = ScalarValue::from(3.0);
 
-        println!("value: {:?}", result_value);
+        println!("value: {result_value:?}");
         assert_eq!(result_value, expected);
     }
 
@@ -730,9 +730,9 @@ mod test_compile {
             ..Default::default()
         };
         let result_expr = compile(&expr, &config, None).unwrap();
-        println!("expr: {:?}", result_expr);
+        println!("expr: {result_expr:?}");
 
         let result_value = result_expr.eval_to_scalar().unwrap();
-        println!("result_value: {:?}", result_value);
+        println!("result_value: {result_value:?}");
     }
 }
